package com.ruoyi.execution.produce.dispersed.service.impl;

import java.util.List;

import com.ruoyi.execution.produce.dispersed.enetity.BpmExecuteNodeMiddle;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.execution.produce.dispersed.mapper.BpmExecuteNodeMiddleMapper;

import com.ruoyi.execution.produce.dispersed.service.IBpmExecuteNodeMiddleService;

/**
 * 执行流程用户、节点关联脚本中间Service业务层处理
 * 
 * @author hzh
 * @date 2023-11-01
 */
@Service
public class BpmExecuteNodeMiddleServiceImpl implements IBpmExecuteNodeMiddleService 
{
    @Autowired
    private BpmExecuteNodeMiddleMapper bpmExecuteNodeMiddleMapper;

    /**
     * 查询执行流程用户、节点关联脚本中间
     * 
     * @param id 执行流程用户、节点关联脚本中间主键
     * @return 执行流程用户、节点关联脚本中间
     */
    @Override
    public BpmExecuteNodeMiddle selectBpmExecuteNodeMiddleById(Long id)
    {
        return bpmExecuteNodeMiddleMapper.selectBpmExecuteNodeMiddleById(id);
    }

    /**
     * 查询执行流程用户、节点关联脚本中间列表
     * 
     * @param bpmExecuteNodeMiddle 执行流程用户、节点关联脚本中间
     * @return 执行流程用户、节点关联脚本中间
     */
    @Override
    public List<BpmExecuteNodeMiddle> selectBpmExecuteNodeMiddleList(BpmExecuteNodeMiddle bpmExecuteNodeMiddle)
    {
        return bpmExecuteNodeMiddleMapper.selectBpmExecuteNodeMiddleList(bpmExecuteNodeMiddle);
    }

    /**
     * 新增执行流程用户、节点关联脚本中间
     * 
     * @param bpmExecuteNodeMiddle 执行流程用户、节点关联脚本中间
     * @return 结果
     */
    @Override
    public int insertBpmExecuteNodeMiddle(BpmExecuteNodeMiddle bpmExecuteNodeMiddle)
    {
        return bpmExecuteNodeMiddleMapper.insertBpmExecuteNodeMiddle(bpmExecuteNodeMiddle);
    }

    /**
     * 修改执行流程用户、节点关联脚本中间
     * 
     * @param bpmExecuteNodeMiddle 执行流程用户、节点关联脚本中间
     * @return 结果
     */
    @Override
    public int updateBpmExecuteNodeMiddle(BpmExecuteNodeMiddle bpmExecuteNodeMiddle)
    {
        return bpmExecuteNodeMiddleMapper.updateBpmExecuteNodeMiddle(bpmExecuteNodeMiddle);
    }

    /**
     * 批量删除执行流程用户、节点关联脚本中间
     * 
     * @param ids 需要删除的执行流程用户、节点关联脚本中间主键
     * @return 结果
     */
    @Override
    public int deleteBpmExecuteNodeMiddleByIds(Long[] ids)
    {
        return bpmExecuteNodeMiddleMapper.deleteBpmExecuteNodeMiddleByIds(ids);
    }

    /**
     * 删除执行流程用户、节点关联脚本中间信息
     * 
     * @param id 执行流程用户、节点关联脚本中间主键
     * @return 结果
     */
    @Override
    public int deleteBpmExecuteNodeMiddleById(Long id)
    {
        return bpmExecuteNodeMiddleMapper.deleteBpmExecuteNodeMiddleById(id);
    }
}
